Method: Aws::SES::Types::SendRawEmailRequest#source_arn

Defined in:
lib/aws-sdk-ses/types.rb

#source_arnString

This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to send for the email address specified in the Source parameter.

For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to send from ‘[email protected]`, then you would specify the SourceArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the Source to be `[email protected]`.

Instead of using this parameter, you can use the X-header X-SES-SOURCE-ARN in the raw message of the email. If you use both the SourceArn parameter and the corresponding X-header, Amazon SES uses the value of the SourceArn parameter.

<note markdown=“1”> For information about when to use this parameter, see the description of SendRawEmail in this guide, or see the [Amazon SES Developer Guide].

</note>

[1]: docs.aws.amazon.com/ses/latest/dg/sending-authorization-delegate-sender-tasks-email.html

Returns:

  • (String)


4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
# File 'lib/aws-sdk-ses/types.rb', line 4379

class SendRawEmailRequest < Struct.new(
  :source,
  :destinations,
  :raw_message,
  :from_arn,
  :source_arn,
  :return_path_arn,
  :tags,
  :configuration_set_name)
  SENSITIVE = []
  include Aws::Structure
end