Method: Aws::SES::Types::EventDestination#enabled

Defined in:
lib/aws-sdk-ses/types.rb

#enabledBoolean

Sets whether Amazon SES publishes events to this destination when you send an email with the associated configuration set. Set to true to enable publishing to this destination; set to false to prevent publishing to this destination. The default value is false.

Returns:

  • (Boolean)


1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-ses/types.rb', line 1565

class EventDestination < Struct.new(
  :name,
  :enabled,
  :matching_event_types,
  :kinesis_firehose_destination,
  :cloud_watch_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end