Class: Aws::SES::Types::ListConfigurationSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ses/types.rb

Overview

Represents a request to list the configuration sets associated with your Amazon Web Services account. Configuration sets enable you to publish email sending events. For information about using configuration sets, see the Amazon SES Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_itemsInteger

The number of configuration sets to return.

Returns:

  • (Integer)


2495
2496
2497
2498
2499
2500
# File 'lib/aws-sdk-ses/types.rb', line 2495

class ListConfigurationSetsRequest < Struct.new(
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token returned from a previous call to ListConfigurationSets to indicate the position of the configuration set in the configuration set list.

Returns:

  • (String)


2495
2496
2497
2498
2499
2500
# File 'lib/aws-sdk-ses/types.rb', line 2495

class ListConfigurationSetsRequest < Struct.new(
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end