Method: Aws::SES::Types::EventDestination#matching_event_types
- Defined in:
- lib/aws-sdk-ses/types.rb
#matching_event_types ⇒ Array<String>
The type of email sending events to publish to the event destination.
-
send- The call was successful and Amazon SES is attempting to deliver the email. -
reject- Amazon SES determined that the email contained a virus and rejected it. -
bounce- The recipient’s mail server permanently rejected the email. This corresponds to a hard bounce. -
complaint- The recipient marked the email as spam. -
delivery- Amazon SES successfully delivered the email to the recipient’s mail server. -
open- The recipient received the email and opened it in their email client. -
click- The recipient clicked one or more links in the email. -
renderingFailure- Amazon SES did not send the email because of a template rendering issue.
1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 |
# File 'lib/aws-sdk-ses/types.rb', line 1565 class EventDestination < Struct.new( :name, :enabled, :matching_event_types, :kinesis_firehose_destination, :cloud_watch_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |