Class: Aws::SES::Types::ListCustomVerificationEmailTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SES::Types::ListCustomVerificationEmailTemplatesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ses/types.rb
Overview
Represents a request to list the existing custom verification email templates for your account.
For more information about custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of custom verification email templates to return.
-
#next_token ⇒ String
An array the contains the name and creation time stamp for each template in your Amazon SES account.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of custom verification email templates to return. This value must be at least 1 and less than or equal to 50. If you do not specify a value, or if you specify a value less than 1 or greater than 50, the operation returns up to 50 results.
2555 2556 2557 2558 2559 2560 |
# File 'lib/aws-sdk-ses/types.rb', line 2555 class ListCustomVerificationEmailTemplatesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An array the contains the name and creation time stamp for each template in your Amazon SES account.
2555 2556 2557 2558 2559 2560 |
# File 'lib/aws-sdk-ses/types.rb', line 2555 class ListCustomVerificationEmailTemplatesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |